@@ -62,12 +62,18 @@ class Table(DbEntity):
                 continue
             if field_name not in self.header:
                 continue
+            if not hasattr(node, field_name):
+                continue
 
             field_val = getattr(node, field_name, None)
             #working for db:
             if isinstance(field_val, Savable):
                 field_type = field_val.annotations['node_id']
                 field_val = field_val.save(True).node_id
+            
+            if (isinstance(field_type, type) and issubclass(field_type, Savable)\
+                and not isinstance(field_val, Savable)):
+                field_type = type(field_val)
                 
             field_val = self.db.cast_py_db_val(field_val, field_type)
 
